"use strict";
var path_1 = require('path');
/**
 * Creates fixture test.
 * `cwd` is set to the case directory during the test.
 * @param ava The ava module function (`import ava from 'ava'`).
 * @param path Absolute or relative path to the fixture cases parent directory. In ava@0.17, cwd for relative path is set to the project root, instead of test file location.
 */
function fixture(ava, path) {
    function curry(testfn) {
        return (function (title, caseName, run) {
            if (!run) {
                // name is optional
                run = caseName;
                caseName = title;
            }
            var fixturePath = path_1.resolve(path, caseName);
            return testfn((title ? title + ' ' : '') + "(fixture: " + caseName + ")", function (t) {
                var result;
                var cwd = process.cwd();
                try {
                    process.chdir(fixturePath);
                    result = run(t, fixturePath, path_1.relative(cwd, fixturePath));
                    if (result && result.then) {
                        return result.then(function (r) {
                            process.chdir(cwd);
                            return r;
                        });
                    }
                }
                finally {
                    process.chdir(cwd);
                }
            });
        });
    }
    var fn = curry(ava);
    var others = {
        only: curry(ava.only),
        skip: curry(ava.skip),
        serial: curry(ava.serial),
        todo: ava.todo,
        cb: curry(ava.cb),
        failing: curry(ava.failing),
        before: ava.before,
        beforeEach: ava.beforeEach,
        after: ava.after,
        afterEach: ava.afterEach
    };
    for (var key in others) {
        fn[key] = others[key];
    }
    return fn; // fn as typeof fn & typeof others;
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = fixture;
//# sourceMappingURL=index.js.map